@@ -1,11 +1,11 @@
 //! @file a68g-defines.h
 //! @author J. Marcel van der Veer
-//!
+
 //! @section Copyright
 //!
 //! This file is part of Algol68G - an Algol 68 compiler-interpreter.
-//! Copyright 2001-2023 J. Marcel van der Veer [algol68g@xs4all.nl].
-//!
+//! Copyright 2001-2025 J. Marcel van der Veer [algol68g@xs4all.nl].
+
 //! @section License
 //!
 //! This program is free software; you can redistribute it and/or modify it 
@@ -66,7 +66,6 @@
 // which may give an undefined reference to `__stack_chk_fail_local'.
 // 
 // -Wno-parentheses-equality is needed for OpenBSD.  
-//
 
 #define A68_GCC_OPTIONS "-DA68_OPTIMISE -ggdb -fno-stack-protector -Wno-parentheses-equality"
 
@@ -80,7 +79,7 @@
 
 #define A68_DIR ".a68g"
 #define A68_HISTORY_FILE ".a68g.edit.hist"
-#define A68_NO_FILENO ((FILE_T) -1)
+#define A68_NO_FILE ((FILE_T) -1)
 #define A68_PROTECTION (S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH)  // -rw-r--r--
 #define A68_READ_ACCESS (O_RDONLY)
 #define A68_WRITE_ACCESS (O_WRONLY | O_CREAT | O_TRUNC)
@@ -90,6 +89,7 @@
 #define EMBEDDED_FORMAT A68_TRUE
 #define EVEN(k) ((k) % 2 == 0)
 #define HIDDEN_TEMP_FILE_NAME ".a68g.tmp"
+#define INTERRUPT_INTERVAL 5
 #define ITEM_NOT_USED (-1)
 #define MAX_ERRORS 5
 #define MAX_PRIORITY 9
@@ -111,15 +111,11 @@
 #define TRANSPUT_BUFFER_SIZE BUFFER_SIZE
 #define WANT_PATTERN A68_TRUE
 
-#define MANT_DIGS(n) ((int) round ((n) * log10 (2.0)))
-#define MANT_BITS(n) ((int) round ((n) / log10 (2.0)))
-#define REAL_DIGITS MANT_DIGS (REAL_MANT_DIG)
-
 // Macros
 
 #define _SKIP_ { (void) 0;}
 
-#define BUFCLR(z) {memset ((z), 0, BUFFER_SIZE + 1);}
+#define BUFCLR(z) {a68_bufset ((z), 0, BUFFER_SIZE + 1);}
 
 #define ABS(n) ((n) >= 0 ? (n) : -(n))
 
@@ -219,21 +215,12 @@
 #define IN_PRELUDE(p) (LINE_NUMBER (p) <= 0)
 #define EOL(c) ((c) == NEWLINE_CHAR || (c) == NULL_CHAR)
 
-#define SIZE_ALIGNED(p) ((int) A68_ALIGN (sizeof (p)))
-#define A68_REF_SIZE (SIZE_ALIGNED (A68_REF))
-#define A68_UNION_SIZE (SIZE_ALIGNED (A68_UNION))
-
-#define A68_SOUND_BYTES(s) ((int) (BITS_PER_SAMPLE (s)) / 8 + (int) (BITS_PER_SAMPLE (s) % 8 == 0 ? 0 : 1))
-#define A68_SOUND_DATA_SIZE(s) ((int) (NUM_SAMPLES (s)) * (int) (NUM_CHANNELS (s)) * (int) (A68_SOUND_BYTES (s)))
 #define BACKWARD(p) (p = PREVIOUS (p))
-#define BITS_WIDTH ((int) (1 + ceil (log ((REAL_T) A68_MAX_INT) / log ((REAL_T) 2))))
 #define DEFLEX(p) (DEFLEXED (p) != NO_MOID ? DEFLEXED(p) : (p))
 #define FORWARD(p) ((p) = NEXT (p))
-#define INT_WIDTH ((int) (1 + floor (log ((REAL_T) A68_MAX_INT) / log ((REAL_T) 10))))
-#define LONG_INT_WIDTH (1 + LONG_WIDTH)
 #define PM(m) (moid_to_string (m, 132, NO_NODE))
 #define SIGN(n) ((n) == 0 ? 0 : ((n) > 0 ? 1 : -1))
-#define WIS(p) where_in_source (STDOUT_FILENO, (p))
+#define WIS(p) where_in_source (A68_STDOUT, (p))
 #define WRITE(f, s) io_write_string ((f), (s));
 #define WRITELN(f, s) {WRITE ((f), "\n"); WRITE ((f), (s));}
 
@@ -368,7 +355,8 @@
 #define HAS_ROWS(p) ((p)->has_rows)
 #define HEAP(p) ((p)->heap)
 #define HEAP_POINTER(p) ((p)->heap_pointer)
-#define H_ADDR(p) ((p)->h_addr)
+// #define H_ADDR(p) ((p)->h_addr) only available with __USE_MISC allowing ancient features (4.3BSD and SysV). 
+#define H_ADDR(p) ((p)->h_addr_list[0]) 
 #define H_LENGTH(p) ((p)->h_length)
 #define ID(p) ((p)->id)
 #define IDENTIFICATION(p) ((p)->identification)
@@ -648,7 +636,7 @@
 #define VALUE_ERROR_MENDED(p) ((p)->value_error_mended)
 #define WARNING_COUNT(p) ((p)->warning_count)
 #define WHERE(p) ((p)->where)
-#define IF_ROW(m) (IS_FLEX (m) || IS_ROW (m) || m == M_STRING)
+#define IS_FLEXETY_ROW(m) (IS_FLEX (m) || IS_ROW (m) || m == M_STRING)
 #define IS_COERCION(p) ((p)->is_coercion)
 #define IS_FLEX(m) IS ((m), FLEX_SYMBOL)
 #define IS_LITERALLY(p, s) (strcmp (NSYMBOL (p), s) == 0)
