@@ -4,7 +4,7 @@
 //! @section Copyright
 //!
 //! This file is part of Algol68G - an Algol 68 compiler-interpreter.
-//! Copyright 2001-2023 J. Marcel van der Veer [algol68g@xs4all.nl].
+//! Copyright 2001-2025 J. Marcel van der Veer [algol68g@xs4all.nl].
 
 //! @section License
 //!
@@ -43,7 +43,7 @@ BOOL_T is_moid_in_pack (MOID_T *, PACK_T *, int);
 BOOL_T is_name_struct (MOID_T *);
 BOOL_T is_nonproc (MOID_T *);
 BOOL_T is_printable_mode (MOID_T *);
-BOOL_T is_proc_ref_file_void_or_format (MOID_T *);
+BOOL_T is_proc_ref_file_void_or_format (const MOID_T *);
 BOOL_T is_readable_mode (MOID_T *);
 BOOL_T is_ref_row (MOID_T *);
 BOOL_T is_rows_type (MOID_T *);
@@ -69,7 +69,7 @@ MOID_T *make_series_from_moids (MOID_T *, MOID_T *);
 MOID_T *make_united_mode (MOID_T *);
 MOID_T *pack_soids_in_moid (SOID_T *, int);
 MOID_T *unites_to (MOID_T *, MOID_T *);
-MOID_T *widens_to (MOID_T *, MOID_T *);
+MOID_T *widens_to (const MOID_T *, const MOID_T *);
 void absorb_series_pack (MOID_T **);
 void absorb_series_union_pack (MOID_T **);
 void add_to_soid_list (SOID_T **, NODE_T *, SOID_T *);
