@@ -4,7 +4,7 @@
 //! @section Copyright
 //!
 //! This file is part of Algol68G - an Algol 68 compiler-interpreter.
-//! Copyright 2001-2023 J. Marcel van der Veer [algol68g@xs4all.nl].
+//! Copyright 2001-2025 J. Marcel van der Veer [algol68g@xs4all.nl].
 
 //! @section License
 //!
@@ -60,12 +60,12 @@ union UFU
 #define NEEDS_DNS(m) (m != NO_MOID && (IS (m, REF_SYMBOL) || IS (m, PROC_SYMBOL) || IS (m, UNION_SYMBOL) || IS (m, FORMAT_SYMBOL)))
 
 #define CODE_EXECUTE(p) {\
-  indentf (out, snprintf (A68 (edit_line), SNPRINTF_SIZE, "GENIE_UNIT_TRACE (_NODE_ (%d));", NUMBER (p)));\
+  indentf (out, a68_bufprt (A68 (edit_line), SNPRINTF_SIZE, "GENIE_UNIT_TRACE (_NODE_ (%d));", NUMBER (p)));\
   }
 
 #define NAME_SIZE 200
 
-BOOK_T *signed_in (int, int, char *);
+BOOK_T *signed_in (int, int, const char *);
 BOOL_T basic_argument (NODE_T *);
 BOOL_T basic_call (NODE_T *);
 BOOL_T basic_collateral (NODE_T *);
@@ -80,7 +80,7 @@ BOOL_T basic_slice (NODE_T *);
 BOOL_T basic_unit (NODE_T *);
 BOOL_T basic_unit (NODE_T *);
 BOOL_T need_initialise_frame (NODE_T *);
-BOOL_T primitive_mode (MOID_T *);
+BOOL_T primitive_mode (const MOID_T *);
 BOOL_T same_tree (NODE_T *, NODE_T *);
 char *compile_call (NODE_T *, FILE_T);
 char *compile_cast (NODE_T *, FILE_T);
@@ -117,7 +117,7 @@ char *gen_voiding_call (NODE_T *, FILE_T, int);
 char *gen_voiding_deproceduring (NODE_T *, FILE_T, int);
 char *gen_voiding_formula (NODE_T *, FILE_T, int);
 char *inline_mode (MOID_T *);
-char *internal_mode (MOID_T *);
+char *internal_mode (const MOID_T *);
 char *make_name (char *, char *, char *, int);
 char *make_unic_name (char *, char *, char *, char *);
 char *moid_with_name (char *, MOID_T *, char *);
